require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module Activity
      class ActivityAttributes < UU::OS::REST::DTO

        # Normalized UESURI of the activity. Never nil.
        attr_accessor :uri

        # Normalized UESURI of the activity template. Nil if the parameter activityType
        # is set.
        attr_accessor :template_uri

        # Type of the activity. See UESActivityType for details. Never nil. Nil if the
        # parameter templateUri is set. @see {ActivityType}
        attr_accessor :activity_type

        # Normalized UESURI of the parent activity. Nil if the activity has no parent activity
        # (when it is located directly on the artifact).
        attr_accessor :parent_activity_uri

        # Name of the activity. Never nil.
        attr_accessor :name

        # Code of the activity. Never nil.
        attr_accessor :code

        # Description of the activity. Never nil.
        attr_accessor :description

        # When the activity was finished. It is not any longer show in the tasklist after this
        # date. Note that activityStateType does not have to be in FINAL or similar state
        # in that case (because dateFinished is also driven by the parent activity). Nil
        # if the activity is not finished yet.
        attr_accessor :date_finished

        # Date from which the activity is shown in the tasklist.
        attr_accessor :date_from

        # Date from which the executive role should perform the activity. It could be different
        # from dateFrom only for activity type TIME_RESERVATION or COVER_MEETING so far.
        # @see {UESActivityType}
        attr_accessor :date_start

        # Date when the executive role should have finished the activity.
        attr_accessor :date_to

        # Date when the activity is automatically finished. The date of expiration is always after the dateTo attribute.
        attr_accessor :date_expiration

        # Normalized UESURI of the competent role of the activity (submitter of the activity).
        # Never nil.
        attr_accessor :competent_role_uri

        # Normalized UESURI of the executive role of the activity (solver of the activity).
        # Never nil.
        attr_accessor :executive_role_uri

        # Related artifact of the activity. Nil if it is not specified.
        attr_accessor :related_artifact_uri

        # Related object of the activity. Nil if it is not specified.
        attr_accessor :related_object_uri

        # Specifies if it is allowed to change the executive role of the activity. Never nil.
        attr_accessor :allow_executive_role_change

        # Specifies if it is allowed to create new subactivities on the activity. Never nil.
        attr_accessor :allow_subactivities

        # Specifies if the activity of type <code>TIME_RESERVATION</code> blocks time
        # in the calendar. Nil for activities of all other types. @see {ActivityType}
        attr_accessor :block_time_in_calendar

        # Type of the current activity state. Nil for planned activity. @see {ActivityStateType}
        attr_accessor :activity_state_type

        # Subtype of the current activity state. Nil for planned activity. @see {ActivityStateSubtype}
        attr_accessor :activity_state_subtype

        # Comment of the current activity state. Nil for planned activities. Nil for planned
        # activity.
        attr_accessor :activity_state_comment

        # Name of the activity state. It is set (from activity state template) when the activity
        # state is set. Nil for planned activities. Nil for planned activity.
        attr_accessor :activity_state_name

        # Identifies whether the activity is recurrent in time.
        attr_accessor :recurrent

        # Version of the activity.
        attr_accessor :version

        # UESURI of the entity type of the activity. Never nil.
        attr_accessor :entity_type_uri

        # Parameters for a macro or other processing tool. Value is a UTF-8 string with the maximum size of 4000 bytes.
        attr_accessor :parameters



        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def template_uri
          attributes[:templateUri]
        end

        def template_uri=(val)
          if val
            attributes[:templateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:templateUri] = nil
          end
        end

        def activity_type
          attributes[:activityType]
        end

        def activity_type=(val)
          attributes[:activityType] = val
        end

        def parent_activity_uri
          attributes[:parentActivityUri]
        end

        def parent_activity_uri=(val)
          if val
            attributes[:parentActivityUri] = UU::OS::UESURI.new(val)
          else
            attributes[:parentActivityUri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def date_finished
          attributes[:dateFinished]
        end

        def date_finished=(val)
          attributes[:dateFinished] = val
        end

        def date_from
          attributes[:dateFrom]
        end

        def date_from=(val)
          attributes[:dateFrom] = val
        end

        def date_start
          attributes[:dateStart]
        end

        def date_start=(val)
          attributes[:dateStart] = val
        end

        def date_to
          attributes[:dateTo]
        end

        def date_to=(val)
          attributes[:dateTo] = val
        end

        def date_expiration
          attributes[:dateExpiration]
        end

        def date_expiration=(val)
          attributes[:dateExpiration] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def executive_role_uri
          attributes[:executiveRoleUri]
        end

        def executive_role_uri=(val)
          if val
            attributes[:executiveRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:executiveRoleUri] = nil
          end
        end

        def related_artifact_uri
          attributes[:relatedArtifactUri]
        end

        def related_artifact_uri=(val)
          if val
            attributes[:relatedArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:relatedArtifactUri] = nil
          end
        end

        def related_object_uri
          attributes[:relatedObjectUri]
        end

        def related_object_uri=(val)
          if val
            attributes[:relatedObjectUri] = UU::OS::UESURI.new(val)
          else
            attributes[:relatedObjectUri] = nil
          end
        end

        def allow_executive_role_change
          attributes[:allowExecutiveRoleChange]
        end

        def allow_executive_role_change=(val)
          attributes[:allowExecutiveRoleChange] = val
        end

        def allow_subactivities
          attributes[:allowSubactivities]
        end

        def allow_subactivities=(val)
          attributes[:allowSubactivities] = val
        end

        def block_time_in_calendar
          attributes[:blockTimeInCalendar]
        end

        def block_time_in_calendar=(val)
          attributes[:blockTimeInCalendar] = val
        end

        def activity_state_type
          attributes[:activityStateType]
        end

        def activity_state_type=(val)
          attributes[:activityStateType] = val
        end

        def activity_state_subtype
          attributes[:activityStateSubtype]
        end

        def activity_state_subtype=(val)
          attributes[:activityStateSubtype] = val
        end

        def activity_state_comment
          attributes[:activityStateComment]
        end

        def activity_state_comment=(val)
          attributes[:activityStateComment] = val
        end

        def activity_state_name
          attributes[:activityStateName]
        end

        def activity_state_name=(val)
          attributes[:activityStateName] = val
        end

        def recurrent
          attributes[:recurrent]
        end

        def recurrent=(val)
          attributes[:recurrent] = val
        end

        def version 
          attributes[:version]
        end

        def version=(val) 
          attributes[:version] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def parameters 
          attributes[:parameters]
        end

        def parameters=(val) 
          attributes[:parameters] = val
        end

      end
    end

  end
end
