require 'uu/os/rest/dto'
require 'uu/os/uesuri'


# Module Unicorn Universe.
module UU
  # Module Operating System.
  module OS
    # Module Activity State Template.
    module ActivityStateTemplate
      # @see ActivityStateTemplate#get_attributes
      class ActivityStateTemplateAttributes < UU::OS::REST::DTO

        # Name of the activity state template.
        attr_accessor :name

        # Code of the activity state template.
        attr_accessor :code

        # Description of the activity state template.
        attr_accessor :description

        # URI of the activity state template.
        attr_accessor :uri

        # URI of the activity template this activity state template is created for.
        attr_accessor :activity_template_uri

        # Type of the activity state template.
        # 
        # @see UU::OS::Activity::ActivityStateType
        attr_accessor :type

        # Subtype of the activity state template.
        # 
        # @see UU::OS::Activity::ActivityStateSubtype
        attr_accessor :subtype

        # Parameter specifies whether activity states set according to this template are entry states
        # of the specified activity.
        attr_accessor :entry_state

        # Parameter specifies whether activity states set according to this template are exit states
        # of the specified activity.
        attr_accessor :exit_state

        # Set of participants who can set activity state according to this template.
        # 
        # @see UU::OS::ActivityStateTemplate::ActivityStateParticipant
        attr_accessor :participants

        # Set of roles which will get a digital workspace record in their digital workspace in the case
        # when an activity is set to the state which is created according to this activity state template.
        # 
        # @see UU::OS::ActivityStateTemplate::ActivityStateVisibility
        attr_accessor :digital_workspace_visibility

        # Creation time of the activity state template.
        attr_accessor :creation_time

        # Modification time of the activity state template.
        attr_accessor :modification_time

        # Version of the activity state template.
        attr_accessor :version

        # URI of the activity state template's icon.
        attr_accessor :icon_uri

        # Order of the activity state template. All activity state templates are suggested to the user
        # in this order when setting the activity state to an activity which is created according
        # to the related activity template.
        attr_accessor :order

        # URI of the entity type of the activity state template.
        attr_accessor :entity_type_uri

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def activity_template_uri
          attributes[:activityTemplateUri]
        end

        def activity_template_uri=(val)
          if val
            attributes[:activityTemplateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:activityTemplateUri] = nil
          end
        end

        def type
          attributes[:type]
        end

        def type=(val)
          attributes[:type] = val
        end

        def subtype
          attributes[:subtype]
        end

        def subtype=(val)
          attributes[:subtype] = val
        end

        def entry_state
          attributes[:entryState]
        end

        def entry_state=(val)
          attributes[:entryState] = val
        end

        def exit_state
          attributes[:exitState]
        end

        def exit_state=(val)
          attributes[:exitState] = val
        end

        def participants
          attributes[:participants]
        end

        def participants=(val)
          attributes[:participants] = val
        end

        def digital_workspace_visibility
          attributes[:digitalWorkspaceVisibility]
        end

        def digital_workspace_visibility=(val)
          attributes[:digitalWorkspaceVisibility] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def order
          attributes[:order]
        end

        def order=(val)
          attributes[:order] = val
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

      end
    end

  end
end
