require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module PersonalAccessRole
      class PersonalAccessRoleSetAttributes < UU::OS::REST::DTO

        # @see PersonalAccessRole#set_attributes
        attr_accessor :first_name

        # @see PersonalAccessRole#set_attributes
        attr_accessor :surname

        # @see PersonalAccessRole#set_attributes
        attr_accessor :code

        # @see PersonalAccessRole#set_attributes
        attr_accessor :description

        # @see PersonalAccessRole#set_attributes
        attr_accessor :security_level

        # @see PersonalAccessRole#set_attributes
        attr_accessor :security_clearance

        # @see PersonalAccessRole#set_attributes
        attr_accessor :searchable_in_territory

        # @see PersonalAccessRole#set_attributes
        attr_accessor :icon_uri

        # @deprecated All From OU will not be used in the new authorization (v4).
        attr_accessor :grant_all_from_organizational_unit
        
        # Indicates whether the primarily displayed content of the personal access role is component content.
        attr_accessor :component_content

        # UES URI or URL of image which represents access role's avatar (user photo). If set to an empty string, the value will be erased. When nil is set, the value is not modified.
        attr_accessor :avatar_uri
        
        def first_name
          attributes[:firstName]
        end

        def first_name=(val)
          attributes[:firstName] = val
        end

        def surname
          attributes[:surname]
        end

        def surname=(val)
          attributes[:surname] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def security_clearance
          attributes[:securityClearance]
        end

        def security_clearance=(val)
          attributes[:securityClearance] = val
        end

        def searchable_in_territory
          attributes[:searchableInTerritory]
        end

        def searchable_in_territory=(val)
          attributes[:searchableInTerritory] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        # @deprecated All From OU will not be used in the new authorization (v4).
        def grant_all_from_organizational_unit
          attributes[:grantAllFromOrganizationalUnit]
        end

        # @deprecated All From OU will not be used in the new authorization (v4).
        def grant_all_from_organizational_unit=(val)
          attributes[:grantAllFromOrganizationalUnit] = val
        end

        def component_content
          attributes[:componentContent]
        end
       
        def component_content=(val)
          attributes[:componentContent] = val
        end
        
        def avatar_uri
          attributes[:avatarUri]
        end
       
        def avatar_uri=(val)
          attributes[:avatarUri] = val
        end
        
      end
    end

  end

end
