require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    module Sheet
      class SheetCreate < UU::OS::REST::DTO

        # Name of the new sheet. When null is set, the name is generated automatically. The
        # name must be unique in a given artifact, otherwise the createcommand fails.
        attr_accessor :name

        # Code of the new sheet. When null is set, the code is generated automatically using
        # the system sequence. The code must be unique in a given artifact,otherwise the
        # create command fails.
        attr_accessor :code

        # Description of the new sheet. When null is set, the description is taken from the
        # template tDescription. When the template does not define a tDescription,it is
        # left empty.
        attr_accessor :description

        # UESURI of the new sheet template. When null is set, template of the default sheet
        # of the given artifact is used.
        attr_accessor :template_uri

        # Specifies if the new sheet is created with empty content. When null is set, content
        # is left intact (it is determined by the content attribute and by thetemplate eventually).
        attr_accessor :empty_content

        # Specifies if the new sheet is set as the main sheet of the specified artifact. When
        # null is set, the new sheet is not set as main. When true is set, thesheet must be visible.
        attr_accessor :main

        # Specifies the order (or index) of the new sheet in the specified artifact. All sheets
        # in an artifact are ordered sequentially. The first sheet has index 0. When null
        # is set or when the order exceeds the number of sheets in the artifact, the sheet is
        # inserted at the end of the sheet list. When 0 or less is set, the sheet is inserted
        # at the beginning of the sheet list. Sheet currently at that position (if any) and
        # any subsequent sheetsare shifted to the right (adds one to their order).
        attr_accessor :order

        # Sheet data. When null is set, the data from template is used.
        attr_accessor :content

        # Version label of the created sheet version. When null is set, versionLabel is left
        # empty.
        attr_accessor :version_label

        # Specifies if the new sheet is set as visible sheet of the specified artifact. When
        # null is set, the visible is taken from the template tVisible. Whenfalse is set,
        # the sheet must not be set as the main of the specified artifact.
        attr_accessor :visible
        
        # Specifies if the editing of the new sheet content in visual is disabled. When false is set,
        # the sheet content cannot be modified in editing or interactive mode (except the elements
        # that have the attribute enabledEditing set to true). The attribute does not block modifying
        # sheet content through API. The default value is true.
        attr_accessor :enabled_editing

        # Flag of width sheet.
        attr_accessor :width
        def name 
          attributes[:name]
        end

        def name=(val) 
          attributes[:name] = val
        end

        def code 
          attributes[:code]
        end

        def code=(val) 
          attributes[:code] = val
        end

        def description 
          attributes[:description]
        end

        def description=(val) 
          attributes[:description] = val
        end

        def template_uri 
          attributes[:templateUri]
        end

        def template_uri=(val) 
          if val
            attributes[:templateUri] = UU::OS::UESURI.new(val)
          else
            attributes[:templateUri] = nil
          end
        end

        def empty_content 
          attributes[:emptyContent]
        end

        def empty_content=(val) 
          attributes[:emptyContent] = val
        end

        def main 
          attributes[:main]
        end

        def main=(val) 
          attributes[:main] = val
        end

        def order 
          attributes[:order]
        end

        def order=(val) 
          attributes[:order] = val
        end

        def content 
          attributes[:content]
        end

        def content=(val) 
          attributes[:content] = val
        end

        def version_label 
          attributes[:versionLabel]
        end

        def version_label=(val) 
          attributes[:versionLabel] = val
        end

        def visible 
          attributes[:visible]
        end

        def visible=(val) 
          attributes[:visible] = val
        end

        def width 
          attributes[:width]
        end

        def width=(val) 
          attributes[:width] = val
        end
        
        def enabled_editing 
          attributes[:enabledEditing]
        end

        def enabled_editing=(val) 
          attributes[:enabledEditing] = val
        end

      end
    end

  end
end
