require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module OS
    
      module UseCaseRealization
        # @deprecated Use {UU::OS::VisualUseCase::VisualUseCaseSetAttributes} instead.
        class UseCaseRealizationSetAttributes < UU::OS::REST::DTO
          
          # The new name of the use case realization. When null is set, the name is not modified.
          attr_accessor :name

          # The new code of the use case realization. When null is set, the code is not modified.
          attr_accessor :code

          # The new description of the use case realization. When null is set, the description is not modified.
          attr_accessor :description

          # Security level of the use case realization. When null is set, the security level is not modified.
          attr_accessor :security_level

          # UESURI of the use case realization icon. When null is set, the icon is not modified.
          # If nil UESURI ("ues:{[-1]}:{[-1]}:") is set, the use case realization icon is removed
          # and the use case realization uses icon from meta artifact.
          #
          # @example Allowed format of icon URI:
          #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{CODE_OF_ICON}
          #
          # @example An example of icon URI:
          #   ues:#{system}:#{ues_v5.core_v1.codetable_v1.base_v1.CodeTable_Icons}:#{ART_077}
          attr_accessor :icon_uri

          # Path at which the controller will be deployed
          attr_accessor :controller_url_path

          # Classs to look for when executing this UCR
          attr_accessor :controller_class
          
          # Engine used for this UCR
          attr_accessor :controller_engine 

          def name 
            attributes[:name]
          end

          def name=(val) 
            attributes[:name] = val
          end

          def code 
            attributes[:code]
          end

          def code=(val) 
            attributes[:code] = val
          end

          def description 
            attributes[:description]
          end

          def description=(val) 
            attributes[:description] = val
          end

          def security_level 
            attributes[:securityLevel]
          end

          def security_level=(val) 
            attributes[:securityLevel] = val
          end

          def icon_uri 
            attributes[:iconUri]
          end

          def icon_uri=(val) 
            if val
              attributes[:iconUri] = UU::OS::UESURI.new(val)
            else
              attributes[:iconUri] = nil
            end
          end

          def controller_url_path 
            attributes[:controllerUrlPath]
          end

          def controller_url_path=(val) 
            attributes[:controllerUrlPath] = val
          end

          def controller_class 
            attributes[:controllerClass]
          end

          def controller_class=(val) 
            attributes[:controllerClass] = val
          end
          
          def controller_engine 
            attributes[:controllerEngine]
          end

          def controller_engine=(val) 
            attributes[:controllerEngine] = val
          end

        end
      end
    end

end
